package at.xaxa.ledger.ui

import android.icu.text.SimpleDateFormat
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.requiredHeight
import androidx.compose.foundation.layout.wrapContentHeight
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.layout.wrapContentWidth
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.DateRange
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.DatePicker
import androidx.compose.material3.DatePickerDialog
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.material3.rememberDatePickerState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.em
import androidx.compose.ui.unit.sp
import java.util.Date
import java.util.Locale

// region Header Card
@Composable
fun HeaderCard(modifier: Modifier = Modifier, balance: String) {
    Surface(
        shape = RoundedCornerShape(12.dp),
        color = Color(0xfff9f9f9),
        border = BorderStroke(1.dp, Color(0xffc6c6c6)),
        modifier = modifier
            .shadow(
                elevation = 8.dp,
                shape = RoundedCornerShape(12.dp),
                clip = false
            )
    ) {
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp)
        ) {
            LayoutMediaTextHeader(modifier, balance)
        }
    }
}

@Composable
fun LayoutMediaTextHeader(modifier: Modifier = Modifier, balance: String) {
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .fillMaxWidth()
    ) {
        Column(
            verticalArrangement = Arrangement.spacedBy(4.dp, Alignment.Top),
            horizontalAlignment = Alignment.End, // Align content to the right
            modifier = Modifier
                .weight(1f)
        ) {
            Text(
                text = "your balance",
                color = Color(0xff1b1b1b),
                lineHeight = 1.5.em,
                style = TextStyle(
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Medium,
                    letterSpacing = 0.15.sp
                )
            )
            Text(
                text = balance,
                color = Color(0xff1b1b1b),
                lineHeight = 1.43.em,
                style = TextStyle(
                    fontSize = 40.sp,
                    letterSpacing = 0.25.sp
                )
            )
        }
    }
}

@Preview()
@Composable
private fun HeaderCardPreview() {
    HeaderCard(Modifier, "-4500627.98€")
}
// endregion

// region Horizontal Card
@Composable
fun HorizontalCard(modifier: Modifier = Modifier, name: String, date: String, amount:String, onClick: () -> Unit ) {
    Surface(
        onClick = onClick,
        shape = RoundedCornerShape(12.dp),
        color = Color(0xfff9f9f9),
        border = BorderStroke(1.dp, Color(0xffc6c6c6)),
        modifier = modifier
            .clip(shape = RoundedCornerShape(12.dp))
    ) {
        Row(
            modifier = Modifier
                .fillMaxSize()
                .padding(16.dp)
        ) {
            LayoutMediaText(modifier, name, date, amount)
        }
    }
}

@Composable
fun LayoutMediaText(modifier: Modifier = Modifier, name: String, date: String, amount:String) {
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .fillMaxWidth()
    ) {
        Column(
            verticalArrangement = Arrangement.spacedBy(4.dp, Alignment.Top),
            modifier = Modifier
                .weight(1f)
        ) {
            Text(
                text = name,
                color = Color(0xff1b1b1b),
                lineHeight = 1.5.em,
                style = TextStyle(
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Medium,
                    letterSpacing = 0.15.sp
                )
            )
            Text(
                text = date,
                color = Color(0xff1b1b1b),
                lineHeight = 1.43.em,
                style = TextStyle(
                    fontSize = 14.sp,
                    letterSpacing = 0.25.sp
                )
            )
        }
        Box(
            modifier = Modifier
                .fillMaxHeight()
                .wrapContentWidth() // Allow the Box to wrap its content width
                .padding(start = 16.dp), // Add some padding to separate from the Column
            contentAlignment = Alignment.Center
        ) {
            Text(
                text = amount,
                fontSize = 30.sp, // Set the desired font size
                modifier = Modifier.wrapContentSize() // Ensure the text wraps its content
            )
        }
    }
}

@Preview(widthDp = 360, heightDp = 80)
@Composable
private fun HorizontalCardPreview() {
    HorizontalCard(Modifier, "McDonald's", "12th Feb, 23:32", "-124234.00€", onClick = { println("success") })
}
// endregion

// region Buttons

//Success
@Composable
fun ButtonSuccess(modifier: Modifier = Modifier, text: String, onClick: () -> Unit) {
   CustomButton(modifier, text, onClick, Color(0xff61a483))
}

@Preview()
@Composable
private fun ButtonSuccessPreview() {
    ButtonSuccess(Modifier, "Success", onClick = { println("success") })
}

//Danger
@Composable
fun ButtonDanger(modifier: Modifier = Modifier, text: String, onClick: () -> Unit) {
    CustomButton(modifier, text, onClick, Color(0xffc14d4d))
}

@Preview()
@Composable
private fun ButtonDangerPreview() {
    ButtonDanger(Modifier, "Danger", onClick = { println("success") })
}

@Composable
private fun CustomButton(modifier: Modifier = Modifier, text: String, onClick: () -> Unit, color: Color){
    Button(
        onClick = onClick,
        shape = RoundedCornerShape(10.dp),
        colors = ButtonDefaults.buttonColors(containerColor = color),
        contentPadding = PaddingValues(horizontal = 24.dp, vertical = 10.dp),
        modifier = modifier
            .shadow(
                elevation = 8.dp,
                shape = RoundedCornerShape(12.dp),
                clip = false
            )
    ) {
        Column(
            verticalArrangement = Arrangement.spacedBy(8.dp, Alignment.CenterVertically),
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .requiredHeight(height = 40.dp)
        ) {
            Row(
                horizontalArrangement = Arrangement.spacedBy(8.dp, Alignment.CenterHorizontally),
                verticalAlignment = Alignment.CenterVertically,
                modifier = Modifier
                    .fillMaxSize()
            ) {
                Text(
                    text = text,
                    color = Color.White,
                    textAlign = TextAlign.Center,
                    lineHeight = 1.43.em,
                    style = MaterialTheme.typography.labelMedium,
                    fontSize = 16.sp,
                    modifier = Modifier
                        .wrapContentHeight(align = Alignment.CenterVertically))
            }
        }
    }
}

// endregion

// region Docked Date Picker

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun DatePickerDocked(onDateSelected: (Long) -> Unit) {
    var showDatePicker by remember { mutableStateOf(false) }
    val datePickerState = rememberDatePickerState()
    val selectedDate = datePickerState.selectedDateMillis?.let {
        convertMillisToDate(it)
    } ?: ""

    Box(
        modifier = Modifier.fillMaxWidth()
    ) {
        OutlinedTextField(
            value = selectedDate,
            onValueChange = { },
            label = { Text("Date") },
            readOnly = true,
            trailingIcon = {
                IconButton(onClick = { showDatePicker = !showDatePicker }) {
                    Icon(
                        imageVector = Icons.Default.DateRange,
                        contentDescription = "Select date"
                    )
                }
            },
            modifier = Modifier
                .fillMaxWidth()
        )

        if (showDatePicker) {
            DatePickerDialog(
                onDismissRequest = { showDatePicker = false },
                confirmButton = {
                    TextButton(
                        onClick = {
                            showDatePicker = false
                            // Notify the parent about the selected date
                            datePickerState.selectedDateMillis?.let { millis ->
                                onDateSelected(millis)
                            }
                        }
                    ) {
                        Text("OK")
                    }
                },
                dismissButton = {
                    TextButton(
                        onClick = { showDatePicker = false }
                    ) {
                        Text("Cancel")
                    }
                }
            ) {
                DatePicker(
                    state = datePickerState,
                    showModeToggle = false
                )
            }
        }
    }
}

fun convertMillisToDate(millis: Long): String {
    val formatter = SimpleDateFormat("DD.MM.yyyy", Locale.getDefault())
    return formatter.format(Date(millis))
}

// endregion